Imports System.Reflection
Imports System.IO

Public Class ReportForm

    Private _reportManager As ReportManager

    Public Sub New(ByVal stateId As String, ByVal fiscalYear As Integer, ByVal comments As String)
        InitializeComponent()
        _reportManager = New ReportManager(stateId, fiscalYear, comments)
    End Sub

    Public Sub New(ByVal reportGuid As System.Guid)
        InitializeComponent()
        _reportManager = New ReportManager(reportGuid)
    End Sub

    Public ReadOnly Property ReportGuid() As System.Guid
        Get
            If _reportManager Is Nothing Then
                Return System.Guid.Empty
            Else
                Return _reportManager.Report.ReportGuid
            End If
        End Get
    End Property

    Private Sub ReportForm_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        SetCaption()
        reportMenuStrip.Hide()  'Hide menu bar 
        SetupSpreadInputMap()
        With formSpread
            .ActiveSheet = .Sheets(0)
            .ActiveSheet.SetActiveCell(1, 1)

        End With
        SetActiveSheet(reportSpread.Sheets(0))  'Display first sheet in spread control
    End Sub

    Private Sub fileCloseToolStripMenuItem_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles fileCloseToolStripMenuItem.Click
        Me.Close()
    End Sub

    Private Sub fileExportClick(ByVal sender As Object, ByVal e As System.EventArgs) _
    Handles fileExportToolStripButton.Click, fileExportToolStripMenuItem.Click
        'show common dialog
        Dim dlg As New SaveFileDialog
        With dlg
            .DefaultExt = "xml"
            .Filter = "XML Document (*.xml)|*.xml|Excel File (*.xls)|*.xls|Text File (*.txt)|*.txt|HTML Document (*.htm)|*.htm"
            .Title = "Export Report As"
            .OverwritePrompt = True
            If .ShowDialog() = Windows.Forms.DialogResult.OK Then
                'save via spread control depending on file type they choose
                Select Case .FileName.Substring(.FileName.Length - 3)
                    Case "xml"
                        reportSpread.ActiveSheet.SaveXml(.FileName)
                    Case "xls"
                        reportSpread.SaveExcel(.FileName)
                    Case "txt"
                        reportSpread.ActiveSheet.SaveTextFile(.FileName, False)
                    Case "htm"
                        reportSpread.ActiveSheet.SaveHtml(.FileName)
                End Select
            End If
        End With
    End Sub

    Private Sub filePrint_Click(ByVal sender As Object, ByVal e As System.EventArgs) _
    Handles filePrintToolStripButton.Click, filePrintToolStripMenuItem.Click
        reportSpread.PrintSheet(-1)
    End Sub

    Private Sub fileSave_Click(ByVal sender As Object, ByVal e As System.EventArgs) _
    Handles fileSaveToolStripButton.Click, fileSaveToolStripMenuItem.Click
        _reportManager.Update()
    End Sub

    Private Sub formSpread_CellClick(ByVal sender As System.Object, ByVal e As FarPoint.Win.Spread.CellClickEventArgs) Handles formSpread.CellClick
        'TODO:  navigate to the appropriate page
        MessageBox.Show(e.Row.ToString)
    End Sub

    Private Sub reportNext_Click(ByVal sender As Object, ByVal e As System.EventArgs) _
    Handles reportNextToolStripMenuItem.Click, reportNextToolStripButton.Click
        With reportSpread
            If .ActiveSheetIndex < .Sheets.Count - 1 Then
                SetActiveSheet(.Sheets(.ActiveSheetIndex + 1))
            End If
        End With
    End Sub

    Private Sub reportPrevious_Click(ByVal sender As Object, ByVal e As System.EventArgs) _
    Handles reportPreviousToolStripMenuItem.Click, reportPreviousToolStripButton.Click
        With reportSpread
            If .ActiveSheetIndex > 0 Then
                SetActiveSheet(.Sheets(.ActiveSheetIndex - 1))
            End If
        End With
    End Sub

    Private Sub reportSpread_SubEditorOpening(ByVal sender As Object, ByVal e As FarPoint.Win.Spread.SubEditorOpeningEventArgs)
        'Don't display pop-up calculator for numeric cell types
        e.Cancel = True
    End Sub

    Private Sub reportSpread_Change(ByVal sender As Object, ByVal e As FarPoint.Win.Spread.ChangeEventArgs)
        Select Case reportSpread.ActiveSheet.SheetName
            Case "ort_part_ia"
                ChangePartIAData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
            Case "ort_part_ib"
                ChangePartIBData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
                ChangePartIBComplainantData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
            Case "ort_part_ic"
                ChangePartICData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
            Case "ort_part_id"
                ChangePartIDData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
            Case "ort_part_ie"
                ChangePartIEData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
            Case "ort_part_if"
                ChangePartIFData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
            Case "ort_part_iia"
                ChangePartIIAData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
            Case "ort_part_iiia"
                ChangePartIIIAData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
            Case "ort_part_iiib"
                ChangePartIIIBData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
            Case "ort_part_iiic"
                ChangePartIIICData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
            Case "ort_part_iiid"
                ChangePartIIIDData(e.Row, e.Column, reportSpread.ActiveSheet.ActiveCell.Value)
        End Select
    End Sub

    Private Sub reportVerifyAll_Click(ByVal sender As Object, ByVal e As System.EventArgs) _
    Handles reportVerifyAllToolStripButton.Click, reportVerifyAllToolStripMenuItem.Click
        Verify()
    End Sub

    Private Sub reportVerifyPage_Click(ByVal sender As Object, ByVal e As System.EventArgs) _
    Handles reportVerifyPageToolStripButton.Click, reportVerifyPageToolStripMenuItem.Click
        Verify(reportSpread.ActiveSheet.SheetName)
    End Sub

    Private Sub verifyDataGridView_CellMouseDoubleClick(ByVal sender As Object, ByVal e As System.Windows.Forms.DataGridViewCellMouseEventArgs) Handles verifyDataGridView.CellMouseDoubleClick
        If e.RowIndex = -1 Then
            Exit Sub
        End If
        If verifyDataGridView.SelectedRows.Count = 0 Then
            Exit Sub
        End If
        ShowError()
    End Sub

    Private Sub verifyDataGridView_KeyDown(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyEventArgs) Handles verifyDataGridView.KeyDown
        If e.KeyCode <> Keys.Enter Then
            Exit Sub
        End If
        If verifyDataGridView.SelectedRows.Count = 0 Then
            Exit Sub
        End If
        e.Handled = True
        ShowError()
    End Sub

    Private Sub SetCaption()
        With _reportManager.Report
            Me.Text = String.Concat(.StateId, " State Annual Ombudsman Report for Federal FY", .FiscalYear.ToString)
        End With
    End Sub

    Private Sub SetupSpreadInputMap()
        'Setup spread control keyboard handling:
        '   Disable F2 clearing cell contents
        '   Map Enter key to move to next column
        '   Map Tab key to move to next control in tab order
        With reportSpread.GetInputMap(FarPoint.Win.Spread.InputMapMode.WhenAncestorOfFocused)
            .Put(New FarPoint.Win.Spread.Keystroke(Keys.F2, Keys.None), FarPoint.Win.Spread.SpreadActions.None)
            .Put(New FarPoint.Win.Spread.Keystroke(Keys.Enter, Keys.None), FarPoint.Win.Spread.SpreadActions.MoveToNextColumnWrap)
            .Put(New FarPoint.Win.Spread.Keystroke(Keys.Tab, Keys.None), FarPoint.Win.Spread.SpreadActions.None)
        End With
    End Sub

    Private Sub SetActiveSheet(ByVal sheetView As FarPoint.Win.Spread.SheetView)
        'Set active sheet
        reportSpread.ActiveSheet = sheetView
        'Display data for this section
        Dim tableName As String = sheetView.SheetName
        ShowSheetData(tableName)
    End Sub

    Private Sub ShowSheetData(ByVal table As String)
        Select Case table
            Case "ort_part_ia"
                ShowPartIAData()
            Case "ort_part_ib"
                ShowPartIBData()
                ShowPartIBComplainantData()
            Case "ort_part_ic"
                ShowPartICData()
            Case "ort_part_id"
                ShowPartIDData()
            Case "ort_part_ie"
                ShowPartIEData()
            Case "ort_part_if"
                ShowPartIFData()
            Case "ort_part_iia"
                ShowPartIIAData()
            Case "ort_part_iiia"
                ShowPartIIIAData()
            Case "ort_part_iiib"
                ShowPartIIIBData()
            Case "ort_part_iiic"
                ShowPartIIICData()
            Case "ort_part_iiid"
                ShowPartIIIDData()
        End Select
    End Sub

    Private Sub ShowPartIAData()
        With reportSpread.ActiveSheet
            .Cells(3, 1).Value = _reportManager.PartIA.total_cases_opened
            .SetActiveCell(3, 1)
        End With
    End Sub

    Private Sub ShowPartIBData()
        reportSpread.ActiveSheet.Cells(18, 2).Value = _reportManager.PartIB.total_complainant_count
    End Sub

    Private Sub ShowPartIBComplainantData()
        reportSpread.ActiveSheet.Cells(8, 1).Value = _reportManager.PartIBComplainant(ComplainantType.Resident, Setting.NursingFacility).complainant_count
        reportSpread.ActiveSheet.Cells(8, 2).Value = _reportManager.PartIBComplainant(ComplainantType.Resident, Setting.BCAlfRlf).complainant_count
        reportSpread.ActiveSheet.Cells(8, 3).Value = _reportManager.PartIBComplainant(ComplainantType.Resident, Setting.OtherSettings).complainant_count

        reportSpread.ActiveSheet.Cells(9, 1).Value = _reportManager.PartIBComplainant(ComplainantType.RelativeOrFriend, Setting.NursingFacility).complainant_count
        reportSpread.ActiveSheet.Cells(9, 2).Value = _reportManager.PartIBComplainant(ComplainantType.RelativeOrFriend, Setting.BCAlfRlf).complainant_count
        reportSpread.ActiveSheet.Cells(9, 3).Value = _reportManager.PartIBComplainant(ComplainantType.RelativeOrFriend, Setting.OtherSettings).complainant_count

        reportSpread.ActiveSheet.Cells(10, 1).Value = _reportManager.PartIBComplainant(ComplainantType.NonRelativeGuardianOrLegalRep, Setting.NursingFacility).complainant_count
        reportSpread.ActiveSheet.Cells(10, 2).Value = _reportManager.PartIBComplainant(ComplainantType.NonRelativeGuardianOrLegalRep, Setting.BCAlfRlf).complainant_count
        reportSpread.ActiveSheet.Cells(10, 3).Value = _reportManager.PartIBComplainant(ComplainantType.NonRelativeGuardianOrLegalRep, Setting.OtherSettings).complainant_count

        reportSpread.ActiveSheet.Cells(11, 1).Value = _reportManager.PartIBComplainant(ComplainantType.OmbudsmanOrVolunteer, Setting.NursingFacility).complainant_count
        reportSpread.ActiveSheet.Cells(11, 2).Value = _reportManager.PartIBComplainant(ComplainantType.OmbudsmanOrVolunteer, Setting.BCAlfRlf).complainant_count
        reportSpread.ActiveSheet.Cells(11, 3).Value = _reportManager.PartIBComplainant(ComplainantType.OmbudsmanOrVolunteer, Setting.OtherSettings).complainant_count

        reportSpread.ActiveSheet.Cells(12, 1).Value = _reportManager.PartIBComplainant(ComplainantType.FacilityAdminOrStaff, Setting.NursingFacility).complainant_count
        reportSpread.ActiveSheet.Cells(12, 2).Value = _reportManager.PartIBComplainant(ComplainantType.FacilityAdminOrStaff, Setting.BCAlfRlf).complainant_count
        reportSpread.ActiveSheet.Cells(12, 3).Value = _reportManager.PartIBComplainant(ComplainantType.FacilityAdminOrStaff, Setting.OtherSettings).complainant_count

        reportSpread.ActiveSheet.Cells(13, 1).Value = _reportManager.PartIBComplainant(ComplainantType.OtherMedical, Setting.NursingFacility).complainant_count
        reportSpread.ActiveSheet.Cells(13, 2).Value = _reportManager.PartIBComplainant(ComplainantType.OtherMedical, Setting.BCAlfRlf).complainant_count
        reportSpread.ActiveSheet.Cells(13, 3).Value = _reportManager.PartIBComplainant(ComplainantType.OtherMedical, Setting.OtherSettings).complainant_count

        reportSpread.ActiveSheet.Cells(14, 1).Value = _reportManager.PartIBComplainant(ComplainantType.AgencyOrProgramRep, Setting.NursingFacility).complainant_count
        reportSpread.ActiveSheet.Cells(14, 2).Value = _reportManager.PartIBComplainant(ComplainantType.AgencyOrProgramRep, Setting.BCAlfRlf).complainant_count
        reportSpread.ActiveSheet.Cells(14, 3).Value = _reportManager.PartIBComplainant(ComplainantType.AgencyOrProgramRep, Setting.OtherSettings).complainant_count

        reportSpread.ActiveSheet.Cells(15, 1).Value = _reportManager.PartIBComplainant(ComplainantType.Unknown, Setting.NursingFacility).complainant_count
        reportSpread.ActiveSheet.Cells(15, 2).Value = _reportManager.PartIBComplainant(ComplainantType.Unknown, Setting.BCAlfRlf).complainant_count
        reportSpread.ActiveSheet.Cells(15, 3).Value = _reportManager.PartIBComplainant(ComplainantType.Unknown, Setting.OtherSettings).complainant_count

        reportSpread.ActiveSheet.Cells(16, 1).Value = _reportManager.PartIBComplainant(ComplainantType.Other, Setting.NursingFacility).complainant_count
        reportSpread.ActiveSheet.Cells(16, 2).Value = _reportManager.PartIBComplainant(ComplainantType.Other, Setting.BCAlfRlf).complainant_count
        reportSpread.ActiveSheet.Cells(16, 3).Value = _reportManager.PartIBComplainant(ComplainantType.Other, Setting.OtherSettings).complainant_count
    End Sub

    Private Sub ShowPartICData()
        reportSpread.ActiveSheet.Cells(3, 1).Value = _reportManager.PartIC.total_complaints_recd_closed_cases
    End Sub

    Private Sub ShowPartIDData()
        reportSpread.ActiveSheet.Cells(158, 2).Value = _reportManager.PartID.total_complaints_by_category_nf
        reportSpread.ActiveSheet.Cells(158, 3).Value = _reportManager.PartID.total_complaints_by_category_bc
        reportSpread.ActiveSheet.Cells(166, 2).Value = _reportManager.PartID.total_complaints_by_category_other
        reportSpread.ActiveSheet.Cells(168, 2).Value = _reportManager.PartID.total_complaints
    End Sub

    Private Sub ShowPartIEData()
        reportSpread.ActiveSheet.Cells(5, 3).Value = _reportManager.PartIE.verified_complaints_nf
        reportSpread.ActiveSheet.Cells(5, 4).Value = _reportManager.PartIE.verified_complaints_bc
        reportSpread.ActiveSheet.Cells(5, 5).Value = _reportManager.PartIE.verified_complaints_other
        reportSpread.ActiveSheet.Cells(21, 3).Value = _reportManager.PartIE.total_complaints_nf
        reportSpread.ActiveSheet.Cells(21, 4).Value = _reportManager.PartIE.total_complaints_bc
        reportSpread.ActiveSheet.Cells(21, 5).Value = _reportManager.PartIE.total_complaints_other
        reportSpread.ActiveSheet.Cells(23, 5).Value = _reportManager.PartIE.complaints_grand_total
        reportSpread.ActiveSheet.Cells(29, 0).Value = _reportManager.PartIE.legal_assistance_remedies
    End Sub

    Private Sub ShowPartIFData()
        reportSpread.ActiveSheet.Cells(5, 0).Value = _reportManager.PartIF.complaint_desc
    End Sub

    Private Sub ShowPartIIAData()
        reportSpread.ActiveSheet.Cells(3, 0).Value = _reportManager.PartIIA.major_ltc_issues
    End Sub

    Private Sub ShowPartIIIAData()
        reportSpread.ActiveSheet.Cells(3, 3).Value = _reportManager.PartIIIA.nursing_facilities
        reportSpread.ActiveSheet.Cells(4, 3).Value = _reportManager.PartIIIA.nursing_facility_beds
        reportSpread.ActiveSheet.Cells(6, 1).Value = _reportManager.PartIIIA.facility_type_names_and_desc
        reportSpread.ActiveSheet.Cells(8, 3).Value = _reportManager.PartIIIA.regulated_nursing_facilities
        reportSpread.ActiveSheet.Cells(9, 3).Value = _reportManager.PartIIIA.regulated_nursing_facility_beds
    End Sub

    Private Sub ShowPartIIIBData()
        reportSpread.ActiveSheet.Cells(10, 3).Value = _reportManager.PartIIIB.aaa
        reportSpread.ActiveSheet.Cells(11, 3).Value = _reportManager.PartIIIB.other_local_govt
        reportSpread.ActiveSheet.Cells(12, 3).Value = _reportManager.PartIIIB.legal_services_provider
        reportSpread.ActiveSheet.Cells(13, 3).Value = _reportManager.PartIIIB.social_services_non_profit
        reportSpread.ActiveSheet.Cells(14, 3).Value = _reportManager.PartIIIB.free_standing_ombudsman
        reportSpread.ActiveSheet.Cells(15, 3).Value = _reportManager.PartIIIB.regional_office_ombudsman
        reportSpread.ActiveSheet.Cells(16, 3).Value = _reportManager.PartIIIB.regional_office_ombudsman
        reportSpread.ActiveSheet.Cells(17, 1).Value = _reportManager.PartIIIB.other_desc
        reportSpread.ActiveSheet.Cells(19, 3).Value = _reportManager.PartIIIB.total_entities
        reportSpread.ActiveSheet.Cells(25, 3).Value = _reportManager.PartIIIB.program_staff_ftes_state
        reportSpread.ActiveSheet.Cells(26, 3).Value = _reportManager.PartIIIB.program_staff_ft_ombudsman_state
        reportSpread.ActiveSheet.Cells(27, 3).Value = _reportManager.PartIIIB.clerical_staff_ftes_state
        reportSpread.ActiveSheet.Cells(28, 3).Value = _reportManager.PartIIIB.certified_volunteers_state
        reportSpread.ActiveSheet.Cells(29, 3).Value = _reportManager.PartIIIB.certified_volunteer_hours_state
        reportSpread.ActiveSheet.Cells(31, 3).Value = _reportManager.PartIIIB.other_volunteers_state
        reportSpread.ActiveSheet.Cells(25, 4).Value = _reportManager.PartIIIB.program_staff_ftes_local
        reportSpread.ActiveSheet.Cells(26, 4).Value = _reportManager.PartIIIB.program_staff_ft_ombudsman_local
        reportSpread.ActiveSheet.Cells(27, 4).Value = _reportManager.PartIIIB.clerical_staff_ftes_local
        reportSpread.ActiveSheet.Cells(28, 4).Value = _reportManager.PartIIIB.certified_volunteers_local
        reportSpread.ActiveSheet.Cells(29, 4).Value = _reportManager.PartIIIB.certified_volunteer_hours_local
        reportSpread.ActiveSheet.Cells(31, 4).Value = _reportManager.PartIIIB.other_volunteers_local
    End Sub

    Private Sub ShowPartIIICData()
        reportSpread.ActiveSheet.Cells(5, 3).Value = _reportManager.PartIIIC.oaa_title_vii_chapter_2_expenditure
        reportSpread.ActiveSheet.Cells(6, 3).Value = _reportManager.PartIIIC.oaa_titlevii_chapter3_expenditure
        reportSpread.ActiveSheet.Cells(7, 3).Value = _reportManager.PartIIIC.oaa_titleiii_state_expenditure
        reportSpread.ActiveSheet.Cells(8, 3).Value = _reportManager.PartIIIC.oaa_titleiii_aaa_expenditure
        reportSpread.ActiveSheet.Cells(9, 3).Value = _reportManager.PartIIIC.other_federal_expenditure
        reportSpread.ActiveSheet.Cells(10, 3).Value = _reportManager.PartIIIC.state_expenditure
        reportSpread.ActiveSheet.Cells(11, 3).Value = _reportManager.PartIIIC.local_expenditure
        reportSpread.ActiveSheet.Cells(12, 1).Value = _reportManager.PartIIIC.other_federal_expenditure_desc
        reportSpread.ActiveSheet.Cells(14, 3).Value = _reportManager.PartIIIC.total_program_funding
    End Sub

    Private Sub ShowPartIIIDData()
        reportSpread.ActiveSheet.Cells(6, 2).Value = _reportManager.PartIIID.training_ombudsman_sessions_state
        reportSpread.ActiveSheet.Cells(6, 3).Value = _reportManager.PartIIID.training_ombudsman_sessions_local
        reportSpread.ActiveSheet.Cells(7, 2).Value = _reportManager.PartIIID.training_ombudsman_hours_state
        reportSpread.ActiveSheet.Cells(7, 3).Value = _reportManager.PartIIID.training_ombudsman_hours_local
        reportSpread.ActiveSheet.Cells(8, 2).Value = _reportManager.PartIIID.training_ombudsman_trainees_state
        reportSpread.ActiveSheet.Cells(8, 3).Value = _reportManager.PartIIID.training_ombudsman_trainees_local
        reportSpread.ActiveSheet.Cells(9, 2).Value = _reportManager.PartIIID.training_ombudsman_topic1_state
        reportSpread.ActiveSheet.Cells(9, 3).Value = _reportManager.PartIIID.training_ombudsman_topic1_local
        reportSpread.ActiveSheet.Cells(10, 2).Value = _reportManager.PartIIID.training_ombudsman_topic2_state
        reportSpread.ActiveSheet.Cells(10, 3).Value = _reportManager.PartIIID.training_ombudsman_topic2_local
        reportSpread.ActiveSheet.Cells(11, 2).Value = _reportManager.PartIIID.training_ombudsman_topic3_state
        reportSpread.ActiveSheet.Cells(11, 3).Value = _reportManager.PartIIID.training_ombudsman_topic3_local
        reportSpread.ActiveSheet.Cells(12, 2).Value = _reportManager.PartIIID.tech_assist_staff_time_percent_state
        reportSpread.ActiveSheet.Cells(12, 3).Value = _reportManager.PartIIID.tech_assist_staff_time_percent_local
        reportSpread.ActiveSheet.Cells(13, 2).Value = _reportManager.PartIIID.training_facility_staff_sessions_state
        reportSpread.ActiveSheet.Cells(13, 3).Value = _reportManager.PartIIID.training_facility_staff_sessions_local
        reportSpread.ActiveSheet.Cells(14, 2).Value = _reportManager.PartIIID.training_facility_staff_topic1_state
        reportSpread.ActiveSheet.Cells(14, 3).Value = _reportManager.PartIIID.training_facility_staff_topic1_local
        reportSpread.ActiveSheet.Cells(15, 2).Value = _reportManager.PartIIID.training_facility_staff_topic2_state
        reportSpread.ActiveSheet.Cells(15, 3).Value = _reportManager.PartIIID.training_facility_staff_topic2_local
        reportSpread.ActiveSheet.Cells(16, 2).Value = _reportManager.PartIIID.training_facility_staff_topic3_state
        reportSpread.ActiveSheet.Cells(16, 3).Value = _reportManager.PartIIID.training_facility_staff_topic3_local
        reportSpread.ActiveSheet.Cells(17, 2).Value = _reportManager.PartIIID.consult_facility_area1_state
        reportSpread.ActiveSheet.Cells(17, 3).Value = _reportManager.PartIIID.consult_facility_area1_local
        reportSpread.ActiveSheet.Cells(18, 2).Value = _reportManager.PartIIID.consult_facility_area2_state
        reportSpread.ActiveSheet.Cells(18, 3).Value = _reportManager.PartIIID.consult_facility_area2_local
        reportSpread.ActiveSheet.Cells(19, 2).Value = _reportManager.PartIIID.consult_facility_area3_state
        reportSpread.ActiveSheet.Cells(19, 3).Value = _reportManager.PartIIID.consult_facility_area3_local
        reportSpread.ActiveSheet.Cells(20, 2).Value = _reportManager.PartIIID.consult_facilities_state
        reportSpread.ActiveSheet.Cells(20, 3).Value = _reportManager.PartIIID.consult_facilities_local
        reportSpread.ActiveSheet.Cells(21, 2).Value = _reportManager.PartIIID.consult_individual_request1_state
        reportSpread.ActiveSheet.Cells(21, 3).Value = _reportManager.PartIIID.consult_individual_request1_local
        reportSpread.ActiveSheet.Cells(22, 2).Value = _reportManager.PartIIID.consult_individual_request2_state
        reportSpread.ActiveSheet.Cells(22, 3).Value = _reportManager.PartIIID.consult_individual_request2_local
        reportSpread.ActiveSheet.Cells(23, 2).Value = _reportManager.PartIIID.consult_individual_request3_state
        reportSpread.ActiveSheet.Cells(23, 3).Value = _reportManager.PartIIID.consult_individual_request3_local
        reportSpread.ActiveSheet.Cells(24, 2).Value = _reportManager.PartIIID.consult_individuals_state
        reportSpread.ActiveSheet.Cells(24, 3).Value = _reportManager.PartIIID.consult_individuals_local
        reportSpread.ActiveSheet.Cells(25, 2).Value = _reportManager.PartIIID.facility_coverage_nf_visited_state
        reportSpread.ActiveSheet.Cells(25, 3).Value = _reportManager.PartIIID.facility_coverage_nf_visited_local
        reportSpread.ActiveSheet.Cells(26, 2).Value = _reportManager.PartIIID.facility_coverage_bc_visited_state
        reportSpread.ActiveSheet.Cells(26, 3).Value = _reportManager.PartIIID.facility_coverage_bc_visited_local
        reportSpread.ActiveSheet.Cells(27, 2).Value = _reportManager.PartIIID.facility_surveys_state
        reportSpread.ActiveSheet.Cells(27, 3).Value = _reportManager.PartIIID.facility_surveys_local
        reportSpread.ActiveSheet.Cells(28, 2).Value = _reportManager.PartIIID.resident_council_meetings_state
        reportSpread.ActiveSheet.Cells(28, 3).Value = _reportManager.PartIIID.resident_council_meetings_local
        reportSpread.ActiveSheet.Cells(29, 2).Value = _reportManager.PartIIID.family_council_meetings_state
        reportSpread.ActiveSheet.Cells(29, 3).Value = _reportManager.PartIIID.family_council_meetings_local
        reportSpread.ActiveSheet.Cells(30, 2).Value = _reportManager.PartIIID.comm_education_sessions_state
        reportSpread.ActiveSheet.Cells(30, 3).Value = _reportManager.PartIIID.comm_education_sessions_local
        reportSpread.ActiveSheet.Cells(31, 2).Value = _reportManager.PartIIID.media_topic1_state
        reportSpread.ActiveSheet.Cells(31, 3).Value = _reportManager.PartIIID.media_topic1_local
        reportSpread.ActiveSheet.Cells(32, 2).Value = _reportManager.PartIIID.media_topic2_state
        reportSpread.ActiveSheet.Cells(32, 3).Value = _reportManager.PartIIID.media_topic2_local
        reportSpread.ActiveSheet.Cells(33, 2).Value = _reportManager.PartIIID.media_topic3_state
        reportSpread.ActiveSheet.Cells(33, 3).Value = _reportManager.PartIIID.media_topic3_local
        reportSpread.ActiveSheet.Cells(34, 2).Value = _reportManager.PartIIID.media_interviews_state
        reportSpread.ActiveSheet.Cells(34, 3).Value = _reportManager.PartIIID.media_interviews_local
        reportSpread.ActiveSheet.Cells(35, 2).Value = _reportManager.PartIIID.media_press_release_state
        reportSpread.ActiveSheet.Cells(35, 3).Value = _reportManager.PartIIID.media_press_release_local
        reportSpread.ActiveSheet.Cells(36, 2).Value = _reportManager.PartIIID.monitoring_staff_time_percent_state
        reportSpread.ActiveSheet.Cells(36, 3).Value = _reportManager.PartIIID.monitoring_staff_time_percent_local
    End Sub

    Private Sub ChangePartIAData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_iaRow = _reportManager.PartIA
        If row = 3 AndAlso column = 1 Then
            dr.total_cases_opened = CType(value, Integer)
        End If
    End Sub

    Private Sub ChangePartIBData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_ibRow = _reportManager.PartIB
        If row = 18 AndAlso column = 2 Then
            dr.total_complainant_count = CType(value, Integer)
        End If
    End Sub

    Private Sub ChangePartIBComplainantData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_ib_complainantRow = Nothing

        If row = 8 And column = 1 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.Resident, Setting.NursingFacility)
        ElseIf row = 8 And column = 2 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.Resident, Setting.BCAlfRlf)
        ElseIf row = 8 And column = 3 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.Resident, Setting.OtherSettings)

        ElseIf row = 9 And column = 1 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.RelativeOrFriend, Setting.NursingFacility)
        ElseIf row = 9 And column = 2 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.RelativeOrFriend, Setting.BCAlfRlf)
        ElseIf row = 9 And column = 3 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.RelativeOrFriend, Setting.OtherSettings)

        ElseIf row = 10 And column = 1 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.NonRelativeGuardianOrLegalRep, Setting.NursingFacility)
        ElseIf row = 10 And column = 2 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.NonRelativeGuardianOrLegalRep, Setting.BCAlfRlf)
        ElseIf row = 10 And column = 3 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.NonRelativeGuardianOrLegalRep, Setting.OtherSettings)

        ElseIf row = 11 And column = 1 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.OmbudsmanOrVolunteer, Setting.NursingFacility)
        ElseIf row = 11 And column = 2 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.OmbudsmanOrVolunteer, Setting.BCAlfRlf)
        ElseIf row = 11 And column = 3 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.OmbudsmanOrVolunteer, Setting.OtherSettings)

        ElseIf row = 12 And column = 1 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.FacilityAdminOrStaff, Setting.NursingFacility)
        ElseIf row = 12 And column = 2 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.FacilityAdminOrStaff, Setting.BCAlfRlf)
        ElseIf row = 12 And column = 3 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.FacilityAdminOrStaff, Setting.OtherSettings)

        ElseIf row = 13 And column = 1 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.OtherMedical, Setting.NursingFacility)
        ElseIf row = 13 And column = 2 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.OtherMedical, Setting.BCAlfRlf)
        ElseIf row = 13 And column = 3 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.OtherMedical, Setting.OtherSettings)

        ElseIf row = 14 And column = 1 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.AgencyOrProgramRep, Setting.NursingFacility)
        ElseIf row = 14 And column = 2 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.AgencyOrProgramRep, Setting.BCAlfRlf)
        ElseIf row = 14 And column = 3 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.AgencyOrProgramRep, Setting.OtherSettings)

        ElseIf row = 15 And column = 1 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.Unknown, Setting.NursingFacility)
        ElseIf row = 15 And column = 2 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.Unknown, Setting.BCAlfRlf)
        ElseIf row = 15 And column = 3 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.Unknown, Setting.OtherSettings)

        ElseIf row = 16 And column = 1 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.Other, Setting.NursingFacility)
        ElseIf row = 16 And column = 2 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.Other, Setting.BCAlfRlf)
        ElseIf row = 16 And column = 3 Then
            dr = _reportManager.PartIBComplainant(ComplainantType.Other, Setting.OtherSettings)
        End If

        If Not dr Is Nothing Then
            dr.complainant_count = CType(value, Integer)
        End If
    End Sub

    Private Sub ChangePartICData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_icRow = _reportManager.PartIC
        If row = 3 AndAlso column = 1 Then
            dr.total_complaints_recd_closed_cases = CType(value, Integer)
        End If
    End Sub

    Private Sub ChangePartIDData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_idRow = _reportManager.PartID
        If row = 158 AndAlso column = 2 Then
            dr.total_complaints_by_category_nf = CType(value, Integer)
        ElseIf row = 158 AndAlso column = 3 Then
            dr.total_complaints_by_category_bc = CType(value, Integer)
        ElseIf row = 166 AndAlso column = 2 Then
            dr.total_complaints_by_category_other = CType(value, Integer)
        ElseIf row = 168 AndAlso column = 2 Then
            dr.total_complaints = CType(value, Integer)
        End If
    End Sub

    Private Sub ChangePartIEData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_ieRow = _reportManager.PartIE

        If row = 5 AndAlso column = 3 Then
            dr.verified_complaints_nf = CType(value, Integer)
        ElseIf row = 5 AndAlso column = 4 Then
            dr.verified_complaints_bc = CType(value, Integer)
        ElseIf row = 5 AndAlso column = 5 Then
            dr.verified_complaints_other = CType(value, Integer)
        ElseIf row = 21 AndAlso column = 3 Then
            dr.total_complaints_nf = CType(value, Integer)
        ElseIf row = 21 AndAlso column = 4 Then
            dr.total_complaints_bc = CType(value, Integer)
        ElseIf row = 21 AndAlso column = 5 Then
            dr.total_complaints_other = CType(value, Integer)
        ElseIf row = 23 AndAlso column = 5 Then
            dr.complaints_grand_total = CType(value, Integer)
        ElseIf row = 29 AndAlso column = 0 Then
            dr.legal_assistance_remedies = String.Concat(String.Concat(CType(value, String), String.Empty), String.Empty)
        End If
    End Sub

    Private Sub ChangePartIFData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_ifRow = _reportManager.PartIF
        If row = 5 AndAlso column = 0 Then
            dr.complaint_desc = String.Concat(CType(value, String), String.Empty)
        End If
    End Sub

    Private Sub ChangePartIIAData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_iiaRow = _reportManager.PartIIA
        If row = 3 AndAlso column = 0 Then
            dr.major_ltc_issues = String.Concat(CType(value, String), String.Empty)
        End If
    End Sub

    Private Sub ChangePartIIIAData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_iiiaRow = _reportManager.PartIIIA
        If row = 3 AndAlso column = 3 Then
            dr.nursing_facilities = CType(value, Integer)
        ElseIf row = 4 AndAlso column = 3 Then
            dr.nursing_facility_beds = CType(value, Integer)
        ElseIf row = 6 AndAlso column = 1 Then
            dr.facility_type_names_and_desc = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 8 AndAlso column = 3 Then
            dr.regulated_nursing_facilities = CType(value, Integer)
        ElseIf row = 9 AndAlso column = 3 Then
            dr.regulated_nursing_facility_beds = CType(value, Integer)
        End If
    End Sub

    Private Sub ChangePartIIIBData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_iiibRow = _reportManager.PartIIIB
        If row = 10 AndAlso column = 3 Then
            dr.aaa = CType(value, Integer)
        ElseIf row = 11 AndAlso column = 3 Then
            dr.other_local_govt = CType(value, Integer)
        ElseIf row = 12 AndAlso column = 3 Then
            dr.legal_services_provider = CType(value, Integer)
        ElseIf row = 13 AndAlso column = 3 Then
            dr.social_services_non_profit = CType(value, Integer)
        ElseIf row = 14 AndAlso column = 3 Then
            dr.free_standing_ombudsman = CType(value, Integer)
        ElseIf row = 15 AndAlso column = 3 Then
            dr.regional_office_ombudsman = CType(value, Integer)
        ElseIf row = 16 AndAlso column = 3 Then
            dr.regional_office_ombudsman = CType(value, Integer)
        ElseIf row = 17 AndAlso column = 1 Then
            dr.other_desc = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 19 AndAlso column = 3 Then
            dr.total_entities = CType(value, Integer)
        ElseIf row = 25 AndAlso column = 3 Then
            dr.program_staff_ftes_state = CType(value, Decimal)
        ElseIf row = 26 AndAlso column = 3 Then
            dr.program_staff_ft_ombudsman_state = CType(value, Integer)
        ElseIf row = 27 AndAlso column = 3 Then
            dr.clerical_staff_ftes_state = CType(value, Decimal)
        ElseIf row = 28 AndAlso column = 3 Then
            dr.certified_volunteers_state = CType(value, Integer)
        ElseIf row = 29 AndAlso column = 3 Then
            dr.certified_volunteer_hours_state = CType(value, Decimal)
        ElseIf row = 31 AndAlso column = 3 Then
            dr.other_volunteers_state = CType(value, Integer)
        ElseIf row = 25 AndAlso column = 4 Then
            dr.program_staff_ftes_local = CType(value, Decimal)
        ElseIf row = 26 AndAlso column = 4 Then
            dr.program_staff_ft_ombudsman_local = CType(value, Integer)
        ElseIf row = 27 AndAlso column = 4 Then
            dr.clerical_staff_ftes_local = CType(value, Decimal)
        ElseIf row = 28 AndAlso column = 4 Then
            dr.certified_volunteers_local = CType(value, Integer)
        ElseIf row = 29 AndAlso column = 4 Then
            dr.certified_volunteer_hours_local = CType(value, Decimal)
        ElseIf row = 31 AndAlso column = 4 Then
            dr.other_volunteers_local = CType(value, Integer)
        End If
    End Sub

    Private Sub ChangePartIIICData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_iiicRow = _reportManager.PartIIIC
        If row = 5 AndAlso column = 3 Then
            dr.oaa_title_vii_chapter_2_expenditure = CType(value, Decimal)
        ElseIf row = 6 AndAlso column = 3 Then
            dr.oaa_titlevii_chapter3_expenditure = CType(value, Decimal)
        ElseIf row = 7 AndAlso column = 3 Then
            dr.oaa_titleiii_state_expenditure = CType(value, Decimal)
        ElseIf row = 8 AndAlso column = 3 Then
            dr.oaa_titleiii_aaa_expenditure = CType(value, Decimal)
        ElseIf row = 9 AndAlso column = 3 Then
            dr.other_federal_expenditure = CType(value, Decimal)
        ElseIf row = 10 AndAlso column = 3 Then
            dr.state_expenditure = CType(value, Decimal)
        ElseIf row = 11 AndAlso column = 3 Then
            dr.local_expenditure = CType(value, Decimal)
        ElseIf row = 12 AndAlso column = 1 Then
            dr.other_federal_expenditure_desc = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 14 AndAlso column = 3 Then
            dr.total_program_funding = CType(value, Decimal)
        End If
    End Sub

    Private Sub ChangePartIIIDData(ByVal row As Integer, ByVal column As Integer, ByVal value As Object)
        Dim dr As ReportingWs.ReportDataSet.ort_part_iiidRow = _reportManager.PartIIID
        If row = 6 AndAlso column = 2 Then
            dr.training_ombudsman_sessions_state = CType(value, Integer)
        ElseIf row = 6 AndAlso column = 3 Then
            dr.training_ombudsman_sessions_local = CType(value, Integer)
        ElseIf row = 7 AndAlso column = 2 Then
            dr.training_ombudsman_hours_state = CType(value, Decimal)
        ElseIf row = 7 AndAlso column = 3 Then
            dr.training_ombudsman_hours_local = CType(value, Decimal)
        ElseIf row = 8 AndAlso column = 2 Then
            dr.training_ombudsman_trainees_state = CType(value, Integer)
        ElseIf row = 8 AndAlso column = 3 Then
            dr.training_ombudsman_trainees_local = CType(value, Integer)
        ElseIf row = 9 AndAlso column = 2 Then
            dr.training_ombudsman_topic1_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 9 AndAlso column = 3 Then
            dr.training_ombudsman_topic1_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 10 AndAlso column = 2 Then
            dr.training_ombudsman_topic2_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 10 AndAlso column = 3 Then
            dr.training_ombudsman_topic2_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 11 AndAlso column = 2 Then
            dr.training_ombudsman_topic3_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 11 AndAlso column = 3 Then
            dr.training_ombudsman_topic3_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 12 AndAlso column = 2 Then
            dr.tech_assist_staff_time_percent_state = CType(value, Decimal)
        ElseIf row = 12 AndAlso column = 3 Then
            dr.tech_assist_staff_time_percent_local = CType(value, Decimal)
        ElseIf row = 13 AndAlso column = 2 Then
            dr.training_facility_staff_sessions_state = CType(value, Integer)
        ElseIf row = 13 AndAlso column = 3 Then
            dr.training_facility_staff_sessions_local = CType(value, Integer)
        ElseIf row = 14 AndAlso column = 2 Then
            dr.training_facility_staff_topic1_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 14 AndAlso column = 3 Then
            dr.training_facility_staff_topic1_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 15 AndAlso column = 2 Then
            dr.training_facility_staff_topic2_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 15 AndAlso column = 3 Then
            dr.training_facility_staff_topic2_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 16 AndAlso column = 2 Then
            dr.training_facility_staff_topic3_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 16 AndAlso column = 3 Then
            dr.training_facility_staff_topic3_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 17 AndAlso column = 2 Then
            dr.consult_facility_area1_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 17 AndAlso column = 3 Then
            dr.consult_facility_area1_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 18 AndAlso column = 2 Then
            dr.consult_facility_area2_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 18 AndAlso column = 3 Then
            dr.consult_facility_area2_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 19 AndAlso column = 2 Then
            dr.consult_facility_area3_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 19 AndAlso column = 3 Then
            dr.consult_facility_area3_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 20 AndAlso column = 2 Then
            dr.consult_facilities_state = CType(value, Integer)
        ElseIf row = 20 AndAlso column = 3 Then
            dr.consult_facilities_local = CType(value, Integer)
        ElseIf row = 21 AndAlso column = 2 Then
            dr.consult_individual_request1_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 21 AndAlso column = 3 Then
            dr.consult_individual_request1_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 22 AndAlso column = 2 Then
            dr.consult_individual_request2_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 22 AndAlso column = 3 Then
            dr.consult_individual_request2_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 23 AndAlso column = 2 Then
            dr.consult_individual_request3_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 23 AndAlso column = 3 Then
            dr.consult_individual_request3_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 24 AndAlso column = 2 Then
            dr.consult_individuals_state = CType(value, Integer)
        ElseIf row = 24 AndAlso column = 3 Then
            dr.consult_individuals_local = CType(value, Integer)
        ElseIf row = 25 AndAlso column = 2 Then
            dr.facility_coverage_nf_visited_state = CType(value, Integer)
        ElseIf row = 25 AndAlso column = 3 Then
            dr.facility_coverage_nf_visited_local = CType(value, Integer)
        ElseIf row = 26 AndAlso column = 2 Then
            dr.facility_coverage_bc_visited_state = CType(value, Integer)
        ElseIf row = 26 AndAlso column = 3 Then
            dr.facility_coverage_bc_visited_local = CType(value, Integer)
        ElseIf row = 27 AndAlso column = 2 Then
            dr.facility_surveys_state = CType(value, Integer)
        ElseIf row = 27 AndAlso column = 3 Then
            dr.facility_surveys_local = CType(value, Integer)
        ElseIf row = 28 AndAlso column = 2 Then
            dr.resident_council_meetings_state = CType(value, Integer)
        ElseIf row = 28 AndAlso column = 3 Then
            dr.resident_council_meetings_local = CType(value, Integer)
        ElseIf row = 29 AndAlso column = 2 Then
            dr.family_council_meetings_state = CType(value, Integer)
        ElseIf row = 29 AndAlso column = 3 Then
            dr.family_council_meetings_local = CType(value, Integer)
        ElseIf row = 30 AndAlso column = 2 Then
            dr.comm_education_sessions_state = CType(value, Integer)
        ElseIf row = 30 AndAlso column = 3 Then
            dr.comm_education_sessions_local = CType(value, Integer)
        ElseIf row = 31 AndAlso column = 2 Then
            dr.media_topic1_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 31 AndAlso column = 3 Then
            dr.media_topic1_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 32 AndAlso column = 2 Then
            dr.media_topic2_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 32 AndAlso column = 3 Then
            dr.media_topic2_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 33 AndAlso column = 2 Then
            dr.media_topic3_state = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 33 AndAlso column = 3 Then
            dr.media_topic3_local = String.Concat(CType(value, String), String.Empty)
        ElseIf row = 34 AndAlso column = 2 Then
            dr.media_interviews_state = CType(value, Integer)
        ElseIf row = 34 AndAlso column = 3 Then
            dr.media_interviews_local = CType(value, Integer)
        ElseIf row = 35 AndAlso column = 2 Then
            dr.media_press_release_state = CType(value, Integer)
        ElseIf row = 35 AndAlso column = 3 Then
            dr.media_press_release_local = CType(value, Integer)
        ElseIf row = 36 AndAlso column = 2 Then
            dr.monitoring_staff_time_percent_state = CType(value, Decimal)
        ElseIf row = 36 AndAlso column = 3 Then
            dr.monitoring_staff_time_percent_local = CType(value, Decimal)
        End If
    End Sub

    Private Sub Verify()
        Verify(String.Empty)
    End Sub

    Private Sub Verify(ByVal part As String)

        'Set busy mouse pointer
        Me.Cursor = Cursors.WaitCursor

        'TODO:  if error pane displayed, clear it
        'TODO:  reset cells

        'Verify section/report
        Dim brokenRules As ArrayList = _reportManager.Verify(part)

        'TODO:  word wrap for descriptions in error list 

        'TODO:  temporary
        dataSplitContainer.Panel2Collapsed = Not dataSplitContainer.Panel2Collapsed
        If dataSplitContainer.Panel2Collapsed = False Then
            With verifyDataGridView
                .Rows.Add("I.B", "A really, really bad error")
                .Rows.Add("III.A", "This is a problem you really ought to fix really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really, really long")
                .Rows.Add("III.B", "You're fucked")
            End With
        End If

        If brokenRules.Count = 0 Then
            'if no broken rules, hide error pane
            'dataSplitContainer.Panel2Collapsed = True
        Else
            'if broken rules exist
            'show error pane
            'dataSplitContainer.Panel2Collapsed = False
        End If

        'Reset mouse pointer
        Me.Cursor = Cursors.Default

        'TODO:  icons for each section verified/unverified

        'If part.Equals(String.Empty) AndAlso brokenRules.Count = 0 Then
        '    Try
        '        Dim reporting As New ReportingWs.Reporting
        '        reporting.VerifyReport(_reportManager.Report.ReportGuid)
        '        MessageBox.Show("The report was verified without error.", "Verify Report", MessageBoxButtons.OK, MessageBoxIcon.Information)
        '    Catch ex As Exception
        '        MessageBox.Show(ex.Message, "ORT", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
        '    End Try
        'Else
        '    For Each brokenRule As String In brokenRules
        '        MessageBox.Show(brokenRule, "Verify", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
        '    Next
        'End If
    End Sub

    Private Sub ShowError()
        'TODO:  show appropriate sheet
        'TODO:  highlight cells in error
        MessageBox.Show("do something")
    End Sub

End Class
